@@ -66,8 +66,6 @@ typedef struct {
 	GtkWidget *workspaces_tree;
 	GtkListStore *workspaces_store;
 
-	GtkWidget *about;
-	
 	GtkOrientation orientation;
 	int n_rows;				/* for vertical layout this is cols */
 	WnckPagerDisplayMode display_mode;
@@ -232,9 +230,6 @@ destroy_pager(GtkWidget * widget, PagerData *pager)
 	if (pager->properties_dialog)
 		gtk_widget_destroy (pager->properties_dialog);
 
-	if (pager->about)
-		gtk_widget_destroy (pager->about);
-
 	g_free (pager);
 }
 
@@ -369,6 +364,7 @@ workspace_switcher_applet_fill (PanelApplet *applet)
 {
 	PagerData *pager;
         GtkActionGroup *action_group;
+	GtkAction *action;
         gchar *ui_path;
 	GError *error;
 	gboolean display_names;
@@ -475,12 +471,11 @@ workspace_switcher_applet_fill (PanelApplet *applet)
 					   ui_path, action_group);
         g_free (ui_path);
 
-	if (panel_applet_get_locked_down (PANEL_APPLET (pager->applet))) {
-                GtkAction *action;
+	action = gtk_action_group_get_action (action_group, "PagerPreferences");
+	g_object_bind_property (pager->applet, "locked-down",
+				action, "visible",
+				G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-                action = gtk_action_group_get_action (action_group, "PagerPreferences");
-                gtk_action_set_visible (action, FALSE);
-	}
         g_object_unref (action_group);
 
 	return TRUE;
