@@ -56,6 +56,7 @@ struct _PanelMenuBarPrivate {
 	AppletInfo  *info;
 	PanelWidget *panel;
 
+	GtkWidget   *image;
 	GtkWidget   *applications_menu;
 	GtkWidget   *applications_item;
 	GtkWidget   *places_item;
@@ -71,6 +72,18 @@ enum {
 
 static void panel_menu_bar_update_text_gravity (PanelMenuBar *menubar);
 
+/* themeable size - "panel-foobar" -- This is only used for the icon of the
+ * Applications item in the menu bar */
+#define PANEL_DEFAULT_MENU_BAR_ICON_SIZE       24
+
+static GtkIconSize panel_menu_bar_icon_size = 0;
+
+static GtkIconSize
+panel_menu_bar_icon_get_size (void)
+{
+	return panel_menu_bar_icon_size;
+}
+
 static gboolean
 panel_menu_bar_reinit_tooltip (GtkWidget    *widget,
 			       PanelMenuBar *menubar)
@@ -134,8 +147,8 @@ panel_menu_bar_setup_tooltip (PanelMenuBar *menubar)
 static void
 panel_menu_bar_init (PanelMenuBar *menubar)
 {
+        GtkStyleContext *context;
         GtkCssProvider *provider;
-	GtkWidget *image;
 
 	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE (menubar);
 
@@ -145,10 +158,12 @@ panel_menu_bar_init (PanelMenuBar *menubar)
                                          " border-width: 0px;\n"
                                          "}",
                                          -1, NULL);
-        gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (menubar)),
+        context = gtk_widget_get_style_context (GTK_WIDGET (menubar));
+        gtk_style_context_add_provider (context,
                                         GTK_STYLE_PROVIDER (provider),
                                         GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
         g_object_unref (provider);
+	gtk_style_context_add_class (context, "gnome-panel-menu-bar");
 
 	menubar->priv->info = NULL;
 
@@ -157,10 +172,8 @@ panel_menu_bar_init (PanelMenuBar *menubar)
 	menubar->priv->applications_item = panel_image_menu_item_new ();
 	gtk_menu_item_set_label (GTK_MENU_ITEM (menubar->priv->applications_item),
 				 _("Applications"));
-	image = gtk_image_new_from_icon_name (PANEL_ICON_MAIN_MENU,
-					      panel_menu_bar_icon_get_size ());
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item),
-				       image);
+	menubar->priv->image = gtk_image_new_from_icon_name (PANEL_ICON_MAIN_MENU,
+							     panel_menu_bar_icon_get_size ());
 
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menubar->priv->applications_item),
 				   menubar->priv->applications_menu);
@@ -283,6 +296,24 @@ panel_menu_bar_size_allocate (GtkWidget     *widget,
 	panel_menu_bar_change_background (PANEL_MENU_BAR (widget));
 }
 
+static void
+panel_menu_bar_style_updated (GtkWidget *widget)
+{
+	PanelMenuBar *menubar = PANEL_MENU_BAR (widget);
+	gboolean      visible;
+
+	GTK_WIDGET_CLASS (panel_menu_bar_parent_class)->style_updated (widget);
+
+	gtk_widget_style_get (widget, "icon-visible", &visible, NULL);
+
+	if (visible)
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item),
+					       menubar->priv->image);
+	else
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item),
+					       NULL);
+}
+
 static void
 panel_menu_bar_class_init (PanelMenuBarClass *klass)
 {
@@ -294,6 +325,7 @@ panel_menu_bar_class_init (PanelMenuBarClass *klass)
 
 	widget_class->parent_set = panel_menu_bar_parent_set;
 	widget_class->size_allocate = panel_menu_bar_size_allocate;
+	widget_class->style_updated = panel_menu_bar_style_updated;
 
 	g_type_class_add_private (klass, sizeof (PanelMenuBarPrivate));
 
@@ -306,6 +338,19 @@ panel_menu_bar_class_init (PanelMenuBarClass *klass)
 				   PANEL_TYPE_ORIENTATION,
 				   PANEL_ORIENTATION_TOP,
 				   G_PARAM_READWRITE));
+
+	gtk_widget_class_install_style_property (
+		widget_class,
+		g_param_spec_boolean ("icon-visible",
+				      "Icon visible",
+				      "Whether the menubar icon is visible",
+				      FALSE,
+				      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+	if (panel_menu_bar_icon_size == 0)
+		panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar",
+								   PANEL_DEFAULT_MENU_BAR_ICON_SIZE,
+								   PANEL_DEFAULT_MENU_BAR_ICON_SIZE);
 }
 
 static gboolean
@@ -357,21 +402,21 @@ panel_menu_bar_load (PanelWidget *panel,
 		return;
 	}
 
-	panel_applet_add_callback (menubar->priv->info,
-				   "help",
-				   GTK_STOCK_HELP,
-				   _("_Help"),
-				   NULL);
-
 	if (panel_is_program_in_path ("alacarte") ||
 	    panel_is_program_in_path ("gmenu-simple-editor")) {
 		panel_applet_add_callback (menubar->priv->info,
 					   "edit",
 					   NULL,
 					   _("_Edit Menus"),
-					   NULL);
+					   panel_lockdown_get_not_locked_down);
 	}
 
+	panel_applet_add_callback (menubar->priv->info,
+				   "help",
+				   GTK_STOCK_HELP,
+				   _("_Help"),
+				   NULL);
+
 	g_signal_connect_after (menubar, "focus-in-event",
 				G_CALLBACK (gtk_widget_queue_draw), menubar);
 	g_signal_connect_after (menubar, "focus-out-event",
